sirocco: Compute topologically certified root continuation of bivariate polynomials
===================================================================================

Description
-----------

sirocco is a library to compute topologically certified root
continuation of bivariate polynomials.

License
-------

GPLv3+


SPKG Maintainers
----------------

-  Miguel Marco


Upstream Contact
----------------

Miguel Marco (mmarco@unizar.es)

Dependencies
------------

-  gcc
